==> eam-wshub-proxyclient-11.5-3-sources.jar: net/datastream/schemas/mp_fields/SERVICECATEGORYSERVICECODEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour SERVICECATEGORYSERVICECODEID_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="SERVICECATEGORYSERVICECODEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICECATEGORYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICEPROBLEMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SERVICECATEGORYSERVICECODEID_Type", propOrder = {
    "servicecategoryid",
    "serviceproblemid"
})
public class SERVICECATEGORYSERVICECODEID_Type {

    @XmlElement(name = "SERVICECATEGORYID", required = true)
    protected PROVIDERSERVICECATEGORYID_Type servicecategoryid;
    @XmlElement(name = "SERVICEPROBLEMID", required = true)
    protected SERVICEPROBLEMID_Type serviceproblemid;

    /**
     * Obtient la valeur de la propriété servicecategoryid.
     * 
     * @return
     *     possible object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public PROVIDERSERVICECATEGORYID_Type getSERVICECATEGORYID() {
        return servicecategoryid;
    }

    /**
     * Définit la valeur de la propriété servicecategoryid.
     * 
     * @param value
     *     allowed object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public void setSERVICECATEGORYID(PROVIDERSERVICECATEGORYID_Type value) {
        this.servicecategoryid = value;
    }

    /**
     * Obtient la valeur de la propriété serviceproblemid.
     * 
     * @return
     *     possible object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public SERVICEPROBLEMID_Type getSERVICEPROBLEMID() {
        return serviceproblemid;
    }

    /**
     * Définit la valeur de la propriété serviceproblemid.
     * 
     * @param value
     *     allowed object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public void setSERVICEPROBLEMID(SERVICEPROBLEMID_Type value) {
        this.serviceproblemid = value;
    }

}

==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_fields/SERVICECATEGORYSERVICECODEID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for SERVICECATEGORYSERVICECODEID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="SERVICECATEGORYSERVICECODEID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICECATEGORYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICEPROBLEMID"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SERVICECATEGORYSERVICECODEID_Type", propOrder = {
    "servicecategoryid",
    "serviceproblemid"
})
public class SERVICECATEGORYSERVICECODEID_Type {

    @XmlElement(name = "SERVICECATEGORYID", required = true)
    protected PROVIDERSERVICECATEGORYID_Type servicecategoryid;
    @XmlElement(name = "SERVICEPROBLEMID", required = true)
    protected SERVICEPROBLEMID_Type serviceproblemid;

    /**
     * Gets the value of the servicecategoryid property.
     * 
     * @return
     *     possible object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public PROVIDERSERVICECATEGORYID_Type getSERVICECATEGORYID() {
        return servicecategoryid;
    }

    /**
     * Sets the value of the servicecategoryid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PROVIDERSERVICECATEGORYID_Type }
     *     
     */
    public void setSERVICECATEGORYID(PROVIDERSERVICECATEGORYID_Type value) {
        this.servicecategoryid = value;
    }

    /**
     * Gets the value of the serviceproblemid property.
     * 
     * @return
     *     possible object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public SERVICEPROBLEMID_Type getSERVICEPROBLEMID() {
        return serviceproblemid;
    }

    /**
     * Sets the value of the serviceproblemid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SERVICEPROBLEMID_Type }
     *     
     */
    public void setSERVICEPROBLEMID(SERVICEPROBLEMID_Type value) {
        this.serviceproblemid = value;
    }

}
